/*
* SACD Decoder plugin
* Copyright (c) 2011-2016 Maxim V.Anisiutkin <maxim.anisiutkin@gmail.com>
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
* License as published by the Free Software Foundation; either
* version 2.1 of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with FFmpeg; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
*/

#include "dsd_stream_service.h"

dsd_chunk_t::dsd_chunk_t() {
	m_samples = 0;
}

dsd_chunk_t::dsd_chunk_t(const t_uint8* p_buffer, t_size p_samples, t_size p_channels, unsigned p_samplerate, unsigned p_channel_config) {
	set_data(p_buffer, p_samples, p_channels, p_samplerate, p_channel_config);
}

t_samplespec dsd_chunk_t::get_spec() {
	return m_spec;
}

t_size dsd_chunk_t::get_channels() {
	return m_spec.m_channels;
}

t_size dsd_chunk_t::get_sample_count() {
	return m_samples;
}

t_size dsd_chunk_t::get_size() {
	return m_spec.m_channels * m_samples;
}

double dsd_chunk_t::get_duration() {
	double duration;
	if (m_spec.m_sample_rate > 0) {
		if (m_spec.m_sample_rate < 2822400) {
			duration = (double)m_samples / (double)m_spec.m_sample_rate;
		}
		else {
			duration = (double)m_samples / (double)(m_spec.m_sample_rate / 8);
		}
	}
	else {
		duration = 0.0;
	}
	return duration;
}

pfc::array_t<t_uint8>& dsd_chunk_t::get_buffer() {
	return m_buffer;
}

t_uint8* dsd_chunk_t::get_data() {
	return m_buffer.get_ptr();
}

void dsd_chunk_t::set_data(const t_uint8* p_buffer, t_size p_samples, t_size p_channels, unsigned p_samplerate, unsigned p_channel_config) {
	m_samples = p_samples;
	m_spec.m_channels = p_channels;
	m_spec.m_sample_rate = p_samplerate;
	m_spec.m_channel_config = p_channel_config;
	t_size buffer_size = m_samples * m_spec.m_channels;
	m_buffer.append_fromptr(reinterpret_cast<const t_uint8*>(p_buffer), buffer_size);
}

const GUID dsd_stream_service::class_guid = { 0x18091b99, 0x3944, 0x4648,{ 0x96, 0xf5, 0x3, 0xa3, 0xa1, 0x3, 0x44, 0xc2 } };
